==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QTextCodec_shell.h <==
#ifndef QTEXTCODEC_SHELL_H
#define QTEXTCODEC_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(textcodec)
#include <QtCore/qtextcodec.h>
#endif //QT_CONFIG(textcodec)
#include <QtJambi/QtJambiAPI>
#include <QTextCodec>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(textcodec)

class QTextCodec_shell : public QTextCodec, public QtJambiShellInterface
{
public:
    QTextCodec_shell();
    ~QTextCodec_shell() override;

    QList<QByteArray> aliases() const override;
    QByteArray convertFromUnicode(const QChar* in0, int length1, QTextCodec::ConverterState* state2) const override;
    QString convertToUnicode(const char* in0, int length1, QTextCodec::ConverterState* state2) const override;
    int mibEnum() const override;
    QByteArray name() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextCodec_access : public QTextCodec
{
    jobject __qt_aliases(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_convertFromUnicode_const_QChar_ptr_int_QTextCodec_ConverterState_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject in0, QtJambiNativeID state2) const;
    jstring __qt_convertToUnicode_const_char_ptr_int_QTextCodec_ConverterState_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject in0, QtJambiNativeID state2) const;
    jint __qt_mibEnum(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_name(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(textcodec)
#endif // QTEXTCODEC_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QTextCodec_shell.h <==
#ifndef QTEXTCODEC_SHELL_H
#define QTEXTCODEC_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(textcodec)
#include <QtCore/qtextcodec.h>
#endif //QT_CONFIG(textcodec)
#include <QtJambi/QtJambiAPI>
#include <QTextCodec>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(textcodec)

class QTextCodec_shell : public QTextCodec, public QtJambiShellInterface
{
public:
    QTextCodec_shell();
    ~QTextCodec_shell() override;

    QList<QByteArray> aliases() const override;
    QByteArray convertFromUnicode(const QChar* in0, int length1, QTextCodec::ConverterState* state2) const override;
    QString convertToUnicode(const char* in0, int length1, QTextCodec::ConverterState* state2) const override;
    int mibEnum() const override;
    QByteArray name() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextCodec_access : public QTextCodec
{
    jobject __qt_aliases_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_convertFromUnicode_const_QChar_ptr_int_QTextCodec_ConverterState_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject in0, QtJambiNativeID state2) const;
    jstring __qt_convertToUnicode_const_char_ptr_int_QTextCodec_ConverterState_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject in0, QtJambiNativeID state2) const;
    jint __qt_mibEnum_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_name_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(textcodec)
#endif // QTEXTCODEC_SHELL_H
